from distutils.core import setup
from setuptools import setup

setup(name="printListModuleAshwin", version ="1.0.0", description="an API to print list recursively", author = "Ashwin", author_email="ashwin.joseph@ignitarium.com", py_modules=["printListModule"])